/*******************************************************************************
 *
 * blueMarine - open source photo workflow
 * =======================================
 *
 * Copyright (C) 2003-2009 by Fabrizio Giudici
 * Project home page: http://bluemarine.tidalwave.it
 *
 *******************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 *
 *******************************************************************************
 *
 * $Id: FormatConverter.java,v b89b0b568aeb 2010/02/17 15:26:52 fabrizio $
 *
 ******************************************************************************/
package it.tidalwave.metadata.viewer.converter;

import it.tidalwave.util.logging.Logger;
import java.text.Format;
import java.text.ParseException;
import javax.annotation.CheckForNull;
import javax.annotation.Nonnull;
import org.jdesktop.beansbinding.Converter;

/*******************************************************************************
 *
 * A {@link Converter} based on {@link Format}.
 *
 * @author  Fabrizio Giudici
 * @version $Id: FormatConverter.java,v b89b0b568aeb 2010/02/17 15:26:52 fabrizio $
 *
 ******************************************************************************/
public class FormatConverter<S> extends Converter<S, String>
  {
    private final static String CLASS = FormatConverter.class.getName();
    private final static Logger logger = Logger.getLogger(CLASS);

    @Nonnull
    private final Format format;
    
    public FormatConverter (@Nonnull final Format format)
      {
        this.format = format;
      }
    
    @Override
    @Nonnull
    public String convertForward (@Nonnull final S object)
      {
        return format.format(object);
      }

    @Override
    @CheckForNull
    public S convertReverse (@Nonnull final String string)
      {
        try 
          {
            return (S)format.parseObject(string);
          } 
        catch (ParseException e) 
          {
            logger.warning("Cannot parse %s: %s", string, e);
            return null;
          }
      }
  }
